##  Define the Sync Scope
To start with, define the sync scope by identifying which data is most meaningful for you as an Enterprise Architect or for your data governance colleagues. Consider the following questions to begin the discussion:
  * What conceptual data is used by which applications and to what extent?
  * How does data flow through the application landscape?
  * Who owns the data?
  * What technical assets exist in our data architecture?
